==> nextcloud-29.0.5.tgz: nextcloud/apps/viewer/l10n/sl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Pregledovalnik",
    "Simple file viewer with slideshow for media" : "Enostaven pregledovalnik datotek z možnostjo predstavitve",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokažite najnovejše fotografije in posnetke s počitnic kot v filmih, pokažite kakšno stran novega romana neposredno iz oblaka, izberite najboljše iz zbirke v neposrednem predogledu priljubljenih datotek in še veliko, veliko več!",
    "Your browser does not support audio." : "Spletni brskalnik ne podpira možnosti predvajanja zvoka.",
    "Error loading {name}" : "Prišlo je do napake med nalaganjem {name}",
    "Image saved" : "Slika je shranjena.",
    "Error saving image" : "Napaka shranjevanja slike",
    "Unsaved changes" : "Neshranjene spremembe",
    "Drop changes" : "Opusti spremembe",
    "Your browser does not support videos." : "Spletni brskalnik ne podpira predvajanja video posnetkov.",
    "Edit" : "Uredi",
    "Exit full screen" : "Končaj celozaslonski način",
    "Full screen" : "Celozaslonski način",
    "Open sidebar" : "Odpri bočno okno",
    "Download" : "Prejmi",
    "Delete" : "Odstrani",
    "This file no longer exists" : "Ta datoteka ne obstaja",
    "There is no plugin available to display this file type" : "Ni vstavka, ki omogoča prikaz te vrste datotek",
    "View" : "Poglej",
    "Name" : "Ime",
    "Save" : "Shrani",
    "Save as" : "Shrani kot",
    "Back" : "Nazaj",
    "Loading …" : "Poteka nalaganje …",
    "Reset" : "Ponastavi",
    "All changes will be lost." : "Vse spremembe bodo izgubljene.",
    "Are you sure you want to continue?" : "Ali ste prepričani, da želite nadaljevati?",
    "Cancel" : "Prekliči",
    "Continue" : "Nadaljuj",
    "Undo" : "Razveljavi",
    "Redo" : "Ponovno uveljavi",
    "Show original image" : "Pokaži izvorno sliko",
    "Zoom in" : "Približaj",
    "Zoom out" : "Oddalji",
    "Toggle zoom menu" : "Meni preklopa približevanja",
    "Adjust" : "Prilagodi",
    "Fine-tune" : "Podrobno prilagajanje",
    "Filters" : "Filtri",
    "Watermark" : "Vodni žig",
    "Draw" : "Risba",
    "Resize" : "Spremeni velikost",
    "Invalid image." : "Neveljavna slika",
    "Error while uploading the image." : "Prišlo je do napake med pošiljanjem slike",
    "are not images" : "niso slike",
    "is not an image" : "ni slika",
    "to be uploaded" : "bo poslano",
    "Crop" : "Obreži",
    "Original" : "Izvorno",
    "Custom" : "Po meri",
    "Square" : "Kvadratno",
    "Landscape" : "Ležeči način",
    "Portrait" : "Pokončni način",
    "Ellipse" : "Elipsa",
    "Classic TV" : "Klasična TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Puščica",
    "Blur" : "Zameglitev",
    "Brightness" : "Svetlost",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Prekliči zrcaljenje po osi X",
    "Flip X" : "Zrcali po osi X",
    "Un-flip Y" : "Prekliči zrcaljenje po osi Y",
    "Flip Y" : "Zrcali po osi Y",
    "HSV" : "HSV",
    "Hue" : "Odtenek",
    "Saturation" : "Nasičenost",
    "Value" : "Vrednost",
    "Image" : "Slika",
    "Importing …" : "Poteka uvažanje ...",
    "+ Add image" : "+ Dodaj sliko",
    "Line" : "Črta",
    "Pen" : "Pisalo",
    "Polygon" : "Mnogokotnik",
    "Sides" : "Drsnice",
    "Rectangle" : "Pravokotnik",
    "Corner Radius" : "Radij robu",
    "Width in pixels" : "Širina v točkah",
    "Height in pixels" : "Višina v točkah",
    "Toggle ratio lock" : "Preklopi zaklep razmerja",
    "Reset to original image size" : "Ponastavi na izvorno velikost slike",
    "Rotate" : "Zavrti",
    "Text" : "Besedilo",
    "Text spacing" : "Razmik besedila",
    "Text alignment" : "Poravnava besedila",
    "Font family" : "Družina pisave",
    "Size" : "Višina",
    "Letter spacing" : "Razmik med črkami",
    "Line height" : "Višina vrstice",
    "Warmth" : "Toplota",
    "+ Add watermark" : "+ Dodaj vodni žig",
    "Choose watermark type" : "Izbor vrste vodnega žiga",
    "Upload watermark" : "Pošlji vodni žig",
    "Add as text" : "Dodaj kot besedilo",
    "Padding" : "Blazinjenje",
    "Shadow" : "Senca",
    "Horizontal" : "Vodoravno",
    "Vertical" : "Navpično",
    "Opacity" : "Prosojnost",
    "Position" : "Položaj",
    "Stroke" : "Poteg",
    "Save image as" : "Shrani sliko kot",
    "Extension" : "Pripona",
    "Name is required." : "Ime mora biti vpisano.",
    "Quality" : "Kakovost",
    "Saved image size (width x height)" : "Velikost shranjene slike (širina x višina)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Izbrano polje obreza je manjše od uveljavljene spremembe velikosti, kar lahko vpliva na zmanjšanje kakovosti slike.",
    "Actual size (100%)" : "Prava velikost (100%)",
    "Fit size" : "Prilagodi velikosti"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-32.0.3.tgz: nextcloud/apps/viewer/l10n/sl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Pregledovalnik",
    "Simple file viewer with slideshow for media" : "Enostaven pregledovalnik datotek z možnostjo predstavitve",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokažite najnovejše fotografije in posnetke s počitnic kot v filmih, pokažite kakšno stran novega romana neposredno iz oblaka, izberite najboljše iz zbirke v neposrednem predogledu priljubljenih datotek in še veliko, veliko več!",
    "Your browser does not support audio." : "Spletni brskalnik ne podpira možnosti predvajanja zvoka.",
    "Error loading {name}" : "Prišlo je do napake med nalaganjem {name}",
    "Cancel" : "Prekliči",
    "Image saved" : "Slika je shranjena.",
    "Error saving image" : "Napaka shranjevanja slike",
    "Your browser does not support videos." : "Spletni brskalnik ne podpira predvajanja video posnetkov.",
    "This file no longer exists" : "Ta datoteka ne obstaja",
    "There is no plugin available to display this file type" : "Ni vstavka, ki omogoča prikaz te vrste datotek",
    "Edit" : "Uredi",
    "Exit full screen" : "Končaj celozaslonski način",
    "Full screen" : "Celozaslonski način",
    "Open sidebar" : "Odpri bočno okno",
    "Download" : "Prejmi",
    "Delete" : "Odstrani",
    "View" : "Poglej",
    "Name" : "Ime",
    "Save" : "Shrani",
    "Save as" : "Shrani kot",
    "Back" : "Nazaj",
    "Loading …" : "Poteka nalaganje …",
    "Reset" : "Ponastavi",
    "All changes will be lost." : "Vse spremembe bodo izgubljene.",
    "Are you sure you want to continue?" : "Ali ste prepričani, da želite nadaljevati?",
    "Apply" : "Uveljavi",
    "Warning" : "Opozorilo",
    "Confirm" : "Potrdi",
    "Discard changes" : "Opusti spremembe",
    "Undo" : "Razveljavi",
    "Redo" : "Ponovno uveljavi",
    "Show original image" : "Pokaži izvorno sliko",
    "Zoom in" : "Približaj",
    "Zoom out" : "Oddalji",
    "Toggle zoom menu" : "Meni preklopa približevanja",
    "Adjust" : "Prilagodi",
    "Fine-tune" : "Podrobno prilagajanje",
    "Filters" : "Filtri",
    "Watermark" : "Vodni žig",
    "Draw" : "Risba",
    "Resize" : "Spremeni velikost",
    "Invalid image." : "Neveljavna slika",
    "Error while uploading the image." : "Prišlo je do napake med pošiljanjem slike",
    "are not images" : "niso slike",
    "is not an image" : "ni slika",
    "to be uploaded" : "bo poslano",
    "Crop" : "Obreži",
    "Original" : "Izvorno",
    "Custom" : "Po meri",
    "Square" : "Kvadratno",
    "Landscape" : "Ležeči način",
    "Portrait" : "Pokončni način",
    "Ellipse" : "Elipsa",
    "Classic TV" : "Klasična TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Puščica",
    "Blur" : "Zameglitev",
    "Brightness" : "Svetlost",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Prekliči zrcaljenje po osi X",
    "Flip X" : "Zrcali po osi X",
    "Un-flip Y" : "Prekliči zrcaljenje po osi Y",
    "Flip Y" : "Zrcali po osi Y",
    "HSV" : "HSV",
    "Hue" : "Odtenek",
    "Saturation" : "Nasičenost",
    "Value" : "Vrednost",
    "Image" : "Slika",
    "Importing …" : "Poteka uvažanje ...",
    "+ Add image" : "+ Dodaj sliko",
    "Line" : "Črta",
    "Pen" : "Pisalo",
    "Polygon" : "Mnogokotnik",
    "Sides" : "Drsnice",
    "Rectangle" : "Pravokotnik",
    "Corner Radius" : "Radij robu",
    "Width in pixels" : "Širina v točkah",
    "Height in pixels" : "Višina v točkah",
    "Toggle ratio lock" : "Preklopi zaklep razmerja",
    "Reset to original image size" : "Ponastavi na izvorno velikost slike",
    "Rotate" : "Zavrti",
    "Text" : "Besedilo",
    "Text spacing" : "Razmik besedila",
    "Text alignment" : "Poravnava besedila",
    "Font family" : "Družina pisave",
    "Size" : "Višina",
    "Letter spacing" : "Razmik med črkami",
    "Line height" : "Višina vrstice",
    "Warmth" : "Toplota",
    "+ Add watermark" : "+ Dodaj vodni žig",
    "Choose watermark type" : "Izbor vrste vodnega žiga",
    "Upload watermark" : "Pošlji vodni žig",
    "Add as text" : "Dodaj kot besedilo",
    "Padding" : "Blazinjenje",
    "Shadow" : "Senca",
    "Horizontal" : "Vodoravno",
    "Vertical" : "Navpično",
    "Opacity" : "Prosojnost",
    "Position" : "Položaj",
    "Stroke" : "Poteg",
    "Save image as" : "Shrani sliko kot",
    "Extension" : "Pripona",
    "Name is required." : "Ime mora biti vpisano.",
    "Quality" : "Kakovost",
    "Saved image size (width x height)" : "Velikost shranjene slike (širina x višina)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Izbrano polje obreza je manjše od uveljavljene spremembe velikosti, kar lahko vpliva na zmanjšanje kakovosti slike.",
    "Actual size (100%)" : "Prava velikost (100%)",
    "Fit size" : "Prilagodi velikosti",
    "Menu" : "Meni",
    "Height" : "Višina"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
